/*
 * Copyright (c) 2012 AgroSense.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    AgroSense - initial API and implementation and/or initial documentation
 */
package nl.cloudfarming.mojo.translate.omegat;

import java.io.File;
import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.shared.model.fileset.FileSet;
import org.apache.maven.shared.model.fileset.util.FileSetManager;

/**
 * Goal which copies OmegaT translation results to your project resources.
 *
 * @goal copy-translations
 * @phase process-resources
 */
public class CopyTranslationsMojo extends AbstractTransferMojo {
    
    @Override
    public void execute() throws MojoExecutionException {
        init();
        
        final FileSetManager fileSetManager = new FileSetManager();
        File resultsDirectory, outputDirectory;
        

        for (FileSet fileset : filesets) {
            getLog().info("Processing fileset for directory: " + fileset.getDirectory());
            String[] includedFiles = fileSetManager.getIncludedFiles(fileset);

            if (includedFiles.length == 0) {
                continue;
            }
            
            // the fileset (input) directory defaults to relative to the module root when not absolute,
            // the outputDirectory we have to check ourselves:
            outputDirectory =  new File(fileset.getOutputDirectory());
            if (!outputDirectory.isAbsolute()) {
                outputDirectory = new File(project.getBasedir(), fileset.getOutputDirectory());
            }            
            getLog().debug("Translation results for this fileset will be copied to: " + outputDirectory);
            
            for (String locale : getTargetLocales()) {
                getLog().info("Processing target locale " + locale);
                // find the translations for the current module+language combination:
                resultsDirectory = new File(getTranslationRootDirectory(), 
                    Utils.join(locale, File.separator, omegatTargetDir, File.separator, project.getArtifactId()));
                
                if (!resultsDirectory.exists()) {
                    getLog().warn("No translations exist yet for module " + project.getArtifactId() + " in locale " + locale);
                    continue;
                }
                
                int count = 0;
                // if a translation exists for a source file, copy it to the output directory of this fileset:
                for (int i = 0; i < includedFiles.length; i++) {
                    String filepath = Utils.getLocalizedFilepath(includedFiles[i], locale);
                    File translation = new File(resultsDirectory, filepath);
                    
                    if (translation.exists()) {
                        File target = new File(outputDirectory, filepath);
                        copyFile(translation, target);
                        count++;
                    }
                }
                if (count < includedFiles.length) {
                    getLog().warn("Translations for module " + project.getArtifactId() + " in locale " + locale + " are still incomplete.");
                }
                getLog().info("Copied " + count + " translations for " + includedFiles.length + " source files");
                
            }
            
            // TODO: create empty files or copies for the source locale;
            // ensure the default bundle will be used instead of falling back to the JVM's default locale;
            // see javadoc for ResourceBundle.getBundle(String baseName, Locale locale, ClassLoader loader)
            // for bundles/properties this file can be empty since ResourceBundle.getObject() will try the parent bundle;
            // for other types we might need to create a copy.
            
            // Copying all types for now:
            getLog().info("Creating copies in source locale");
            for (int i = 0; i < includedFiles.length; i++) {
                File source = new File(fileset.getDirectory(), includedFiles[i]);
                File target = new File(outputDirectory, Utils.getLocalizedFilepath(includedFiles[i], getSourceLocale()));
                copyFile(source, target);
            }
        }
        
    }
}
