/*
 * Copyright (c) 2012 AgroSense.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    AgroSense - initial API and implementation and/or initial documentation
 */
package nl.cloudfarming.mojo.translate.omegat;


import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.Arrays;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import org.apache.maven.plugin.MojoExecutionException;
import org.codehaus.plexus.util.IOUtil;
import org.codehaus.plexus.util.StringUtils;

/**
 *
 * @author johan
 */
public class OmegatProject {
    private OmegatProject() {}
    
    public static final String PROJECT_TEMPLATE = "/nl/cloudfarming/mojo/translate/omegat/omegat.project";
    public static final String PROJECT_FILENAME = "omegat.project";
    // all standard folders except sources (shared), and target (configurable):
    public static final String[] STANDARD_PROJECT_FOLDERS = {"dictionary", "glossary", "omegat", "tm", "tm" + File.separator + "auto"};
    
    /**
     * Setup an empty OmegaT translation project.
     * 
     * <ul>
     * <li>create the default directory structure, except for the source directory since that one will be shared</li>
     * <li>create the project file from a template</li>
     * </ul>
     * 
     * @param projectDirectory
     * @param sourceLang locale string in OmegaT format
     * @param targetLang locale string in OmegaT format
     */
    public static void create(File projectDirectory, final String sourceLang, final String targetLang, final String targetDir) throws MojoExecutionException {
        List<String> dirNames = new LinkedList<>();
        dirNames.addAll(Arrays.asList(STANDARD_PROJECT_FOLDERS));
        dirNames.add(targetDir);
        
        for (String dirName : dirNames) {
            new File(projectDirectory, dirName).mkdirs();
        }
        
        String template;
        try (InputStream is = Utils.class.getResourceAsStream(PROJECT_TEMPLATE)) {
            template = IOUtil.toString(is);
        } catch (IOException ex) {
            throw new MojoExecutionException("Could not read omegat project template", ex);
        }
        
        String projectXML = StringUtils.interpolate(template, new HashMap<String,String>() {{
            put("sourceLang", sourceLang);
            put("targetLang", targetLang);
            put("targetDir", targetDir);
        }});
        File projectFile = new File(projectDirectory, PROJECT_FILENAME);

        try (FileOutputStream fos = new FileOutputStream(projectFile)) {
            IOUtil.copy(projectXML, fos);
        } catch (IOException ex) {
           throw new MojoExecutionException("Could not write omegat project file", ex);
        }
    }
}
