/*
 * Copyright (c) 2012 AgroSense.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    AgroSense - initial API and implementation and/or initial documentation
 */
package nl.cloudfarming.mojo.translate.omegat;

import java.io.File;
import org.apache.commons.lang3.LocaleUtils;
import org.apache.maven.plugin.MojoExecutionException;

/**
 *
 * @author johan
 */
public class Utils {
    private Utils() {}
    
    /**
     * Validate if the provided string represents a locale.
     * 
     * @param str the string to validate
     * @return 
     * @throws MojoExecutionException 
     */
    public static String validateLocaleString(String str) throws MojoExecutionException {
        str = str.trim();
        try {
            LocaleUtils.toLocale(str);
        } catch(IllegalArgumentException e) {
            throw new MojoExecutionException("Invalid locale string: " + str, e);
        }
        return str;
    }

    /**
     * Create a localized version of a file name.
     * 
     * The basename of the file will be suffixed with the locale string.
     * 
     * @param filepath a filename, possibly including one or more parent directories.
     * @param locale
     * @return localized version of the file path
     */
    public static String getLocalizedFilepath(String filepath, String locale) {
        String parent, filename, basename, extension;
        
        int i = filepath.lastIndexOf(File.separatorChar);
        if (i != -1) {
            parent = filepath.substring(0, i + 1);
            filename = filepath.substring(i + 1);
        } else {
            parent = "";
            filename = filepath;
        }
        
        int j = filename.lastIndexOf('.');
        if (j > 0) {
            basename = filename.substring(0, j);
            extension = filename.substring(j);
        } else{
            basename = filename;
            extension = "";
        }
        
        return join(parent, basename, "_" , locale, extension);
    }
    
    /**
     * Join strings without using a separator.
     * 
     * @param strings
     * @return 
     */
    public static String join(String... strings) {
        StringBuilder sb = new StringBuilder();
        for (String s : strings) { sb.append(s); }
        return sb.toString();
    }

    /**
     * Convert a locale string to the format used by the OmegaT project files.
     * 
     * @param locale
     * @return
     */
    public static String toOmegatLang(String locale) {
        return locale.replace('_', '-').toUpperCase();
    }    
}
